Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/sommerfeld_i386mp_1]: src/sys/arch/i386/i386 Adjust mapping of local api...



details:   https://anonhg.NetBSD.org/src/rev/facad9781ee0
branches:  sommerfeld_i386mp_1
changeset: 482200:facad9781ee0
user:      sommerfeld <sommerfeld%NetBSD.org@localhost>
date:      Wed Feb 23 06:10:50 2000 +0000

description:
Adjust mapping of local apic yet again.

diffstat:

 sys/arch/i386/i386/lapic.c |  6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diffs (27 lines):

diff -r d567c30576c7 -r facad9781ee0 sys/arch/i386/i386/lapic.c
--- a/sys/arch/i386/i386/lapic.c        Mon Feb 21 21:53:57 2000 +0000
+++ b/sys/arch/i386/i386/lapic.c        Wed Feb 23 06:10:50 2000 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: lapic.c,v 1.1.2.7 2000/02/21 21:10:28 sommerfeld Exp $ */
+/* $NetBSD: lapic.c,v 1.1.2.8 2000/02/23 06:10:50 sommerfeld Exp $ */
 
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -91,7 +91,7 @@
 
        /*
         * Map local apic.  If we have a local apic, it's safe to assume
         * we're on a 486 or better and can use invpg and non-cacheable PTE's
         *
         * Whap the PTE "by hand" rather than calling pmap_kenter_pa because
         * the latter will attempt to invoke TLB shootdown code just as we
@@ -100,7 +100,7 @@
 
        pte = kvtopte(va);
        *pte = lapic_base | PG_RW | PG_V | PG_N | pmap_pg_g;
-       pmap_update_pg(va);
+       invlpg(va);
 
 #ifdef MULTIPROCESSOR
        cpu_init_first();       /* catch up to changed cpu_number() */
@@ -91,7 +91,7 @@
        /*
         * Map local apic.  If we have a local apic, it's safe to assume
-        * we're on a 486 or better and can use invpg and non-cacheable PTE's
+        * we're on a 486 or better and can use invlpg and non-cacheable PTE's
         *
         * Whap the PTE "by hand" rather than calling pmap_kenter_pa because



Home | Main Index | Thread Index | Old Index